==> vue-create-web-0.1.0.tgz: package/es/components/controls/echarts/BarChart.js <==
import "core-js/modules/es.array.map.js";
import "core-js/modules/es.object.to-string.js";
import "core-js/modules/es.regexp.to-string.js";
import _classCallCheck from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/createClass";
import _inherits from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/inherits";
import _createSuper from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/createSuper";
import { __decorate } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import { mixins } from 'vue-class-component';
import BaseChart from './BaseChart';
import { withInstall } from '@/util';
var xAxisData = [];
var data = [];
var data2 = [];

for (var i = 0; i < 50; i++) {
  xAxisData.push(i.toString());
  data.push((Math.sin(i / 5) * (i / 5 - 10) + i / 6) * 5);
  data2.push((Math.sin(i / 5) * (i / 5 + 10) + i / 6) * 3);
}

export var defaultData = {
  xAxisData: xAxisData,
  data: data,
  data2: data2
};
export var defaultOption = {
  backgroundColor: '#08263a',
  grid: {
    left: '5%',
    right: '5%'
  },
  xAxis: [{
    show: false,
    data: xAxisData
  }, {
    show: false,
    data: xAxisData
  }],
  visualMap: [{
    show: false,
    min: 0,
    max: 50,
    dimension: 0,
    inRange: {
      color: ['#4a657a', '#308e92', '#b1cfa5', '#f5d69f', '#f5898b', '#ef5055']
    }
  }],
  yAxis: [{
    axisLine: {
      show: false
    },
    axisLabel: {
      color: '#43657a'
    },
    splitLine: {
      show: true,
      lineStyle: {
        color: '#08263f'
      }
    },
    axisTick: {
      show: false
    }
  }],
  series: [{
    name: 'back',
    type: 'bar',
    data: data2,
    z: 1,
    itemStyle: {
      opacity: 0.4,
      barBorderRadius: 5,
      shadowBlur: 3,
      shadowColor: '#111'
    }
  }, {
    name: 'Simulate Shadow',
    type: 'line',
    data: data,
    z: 2,
    showSymbol: false,
    animationDelay: 0,
    animationEasing: 'linear',
    animationDuration: 1200,
    lineStyle: {
      color: 'transparent'
    },
    areaStyle: {
      color: '#08263a',
      shadowBlur: 50,
      shadowColor: '#000'
    }
  }, {
    name: 'front',
    type: 'bar',
    data: data,
    xAxisIndex: 1,
    z: 3,
    itemStyle: {
      barBorderRadius: 5
    }
  }],
  animationEasing: 'elasticOut',
  animationEasingUpdate: 'elasticOut',
  animationDelay: function animationDelay(idx) {
    return idx * 20;
  },
  animationDelayUpdate: function animationDelayUpdate(idx) {
    return idx * 20;
  }
};

var BarChart = /*#__PURE__*/function (_mixins) {
  _inherits(BarChart, _mixins);

  var _super = _createSuper(BarChart);

  function BarChart() {
    _classCallCheck(this, BarChart);

    return _super.apply(this, arguments);
  }

  _createClass(BarChart, [{
    key: "mounted",
    value: function mounted() {}
  }, {
    key: "options",
    get: function get() {
      var _this = this;

      if (this.chartOption.xAxis && Array.isArray(this.chartOption.xAxis)) {
        this.chartOption.xAxis.map(function (item) {
          return item.data = _this.chartData.xAxisData;
        });
      }

      if (this.chartOption.series && Array.isArray(this.chartOption.series)) {
        this.chartOption.series[0] && (this.chartOption.series[0].data = this.chartData.data2);
        this.chartOption.series[1] && (this.chartOption.series[1].data = this.chartData.data);
        this.chartOption.series[2] && (this.chartOption.series[2].data = this.chartData.data);
      }

      return this.chartOption;
    }
  }]);

  return BarChart;
}(mixins(BaseChart));

__decorate([Prop({
  default: function _default() {
    return defaultData;
  }
})], BarChart.prototype, "chartData", void 0);

__decorate([Prop({
  default: function _default() {
    return defaultOption;
  }
})], BarChart.prototype, "chartOption", void 0);

BarChart = __decorate([Component({
  name: 'BarChart',
  categrey: 'echart图表',
  zhName: '柱状图',
  iconType: 'bar-chart'
})], BarChart);
export default withInstall(BarChart);

==> vue-create-web-0.1.2.tgz: package/es/components/controls/echarts/BarChart.js <==
import "core-js/modules/es.array.map.js";
import "core-js/modules/es.object.to-string.js";
import "core-js/modules/es.regexp.to-string.js";
import _classCallCheck from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/createClass";
import _inherits from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/inherits";
import _createSuper from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/createSuper";
import { __decorate } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import { mixins } from 'vue-class-component';
import BaseChart from './BaseChart';
import { withInstall } from '../../../util';
var xAxisData = [];
var data = [];
var data2 = [];

for (var i = 0; i < 50; i++) {
  xAxisData.push(i.toString());
  data.push((Math.sin(i / 5) * (i / 5 - 10) + i / 6) * 5);
  data2.push((Math.sin(i / 5) * (i / 5 + 10) + i / 6) * 3);
}

export var defaultData = {
  xAxisData: xAxisData,
  data: data,
  data2: data2
};
export var defaultOption = {
  backgroundColor: '#08263a',
  grid: {
    left: '5%',
    right: '5%'
  },
  xAxis: [{
    show: false,
    data: xAxisData
  }, {
    show: false,
    data: xAxisData
  }],
  visualMap: [{
    show: false,
    min: 0,
    max: 50,
    dimension: 0,
    inRange: {
      color: ['#4a657a', '#308e92', '#b1cfa5', '#f5d69f', '#f5898b', '#ef5055']
    }
  }],
  yAxis: [{
    axisLine: {
      show: false
    },
    axisLabel: {
      color: '#43657a'
    },
    splitLine: {
      show: true,
      lineStyle: {
        color: '#08263f'
      }
    },
    axisTick: {
      show: false
    }
  }],
  series: [{
    name: 'back',
    type: 'bar',
    data: data2,
    z: 1,
    itemStyle: {
      opacity: 0.4,
      barBorderRadius: 5,
      shadowBlur: 3,
      shadowColor: '#111'
    }
  }, {
    name: 'Simulate Shadow',
    type: 'line',
    data: data,
    z: 2,
    showSymbol: false,
    animationDelay: 0,
    animationEasing: 'linear',
    animationDuration: 1200,
    lineStyle: {
      color: 'transparent'
    },
    areaStyle: {
      color: '#08263a',
      shadowBlur: 50,
      shadowColor: '#000'
    }
  }, {
    name: 'front',
    type: 'bar',
    data: data,
    xAxisIndex: 1,
    z: 3,
    itemStyle: {
      barBorderRadius: 5
    }
  }],
  animationEasing: 'elasticOut',
  animationEasingUpdate: 'elasticOut',
  animationDelay: function animationDelay(idx) {
    return idx * 20;
  },
  animationDelayUpdate: function animationDelayUpdate(idx) {
    return idx * 20;
  }
};

var BarChart = /*#__PURE__*/function (_mixins) {
  _inherits(BarChart, _mixins);

  var _super = _createSuper(BarChart);

  function BarChart() {
    _classCallCheck(this, BarChart);

    return _super.apply(this, arguments);
  }

  _createClass(BarChart, [{
    key: "mounted",
    value: function mounted() {}
  }, {
    key: "options",
    get: function get() {
      var _this = this;

      if (this.chartOption.xAxis && Array.isArray(this.chartOption.xAxis)) {
        this.chartOption.xAxis.map(function (item) {
          return item.data = _this.chartData.xAxisData;
        });
      }

      if (this.chartOption.series && Array.isArray(this.chartOption.series)) {
        this.chartOption.series[0] && (this.chartOption.series[0].data = this.chartData.data2);
        this.chartOption.series[1] && (this.chartOption.series[1].data = this.chartData.data);
        this.chartOption.series[2] && (this.chartOption.series[2].data = this.chartData.data);
      }

      return this.chartOption;
    }
  }]);

  return BarChart;
}(mixins(BaseChart));

__decorate([Prop({
  default: function _default() {
    return defaultData;
  }
})], BarChart.prototype, "chartData", void 0);

__decorate([Prop({
  default: function _default() {
    return defaultOption;
  }
})], BarChart.prototype, "chartOption", void 0);

BarChart = __decorate([Component({
  name: 'BarChart',
  categrey: 'echart图表',
  zhName: '柱状图',
  iconType: 'bar-chart'
})], BarChart);
export default withInstall(BarChart);
